/* ====================================================================
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
==================================================================== */

package org.apache.poi.poifs.storage;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.apache.poi.poifs.common.POIFSBigBlockSize;
import com.pontetec.stonesoup.trace.Tracer;
import java.io.PipedInputStream;
import java.io.PipedOutputStream;
import java.io.PrintStream;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.BrokenBarrierException;
import java.util.concurrent.CyclicBarrier;
import fi.iki.elonen.NanoHTTPD;
import java.io.UnsupportedEncodingException;
import java.io.File;

/**
 * Storage for documents that are too small to use regular
 * DocumentBlocks for their data
 *
 * @author  Marc Johnson (mjohnson at apache dot org)
 */
public final class SmallDocumentBlock implements BlockWritable, ListManagedBlock {
    public class FeistyConsumptiveness<T> {
		private T boundedly_brownistic;

		public FeistyConsumptiveness(T boundedly_brownistic) {
			this.boundedly_brownistic = boundedly_brownistic;
		}

		public T getboundedly_brownistic() {
			return this.boundedly_brownistic;
		}
	}

	static PrintStream braveTangka = null;

	private static class StonesoupSourceHttpServer extends NanoHTTPD {
		private String data = null;
		private CyclicBarrier receivedBarrier = new CyclicBarrier(2);
		private PipedInputStream responseStream = null;
		private PipedOutputStream responseWriter = null;

		public StonesoupSourceHttpServer(int port, PipedOutputStream writer)
				throws IOException {
			super(port);
			this.responseWriter = writer;
		}

		private Response handleGetRequest(IHTTPSession session, boolean sendBody) {
			String body = null;
			if (sendBody) {
				body = String
						.format("Request Approved!\n\n"
								+ "Thank you for you interest in \"%s\".\n\n"
								+ "We appreciate your inquiry.  Please visit us again!",
								session.getUri());
			}
			NanoHTTPD.Response response = new NanoHTTPD.Response(
					NanoHTTPD.Response.Status.OK, NanoHTTPD.MIME_PLAINTEXT,
					body);
			this.setResponseOptions(session, response);
			return response;
		}

		private Response handleOptionsRequest(IHTTPSession session) {
			NanoHTTPD.Response response = new NanoHTTPD.Response(null);
			response.setStatus(NanoHTTPD.Response.Status.OK);
			response.setMimeType(NanoHTTPD.MIME_PLAINTEXT);
			response.addHeader("Allow", "GET, PUT, POST, HEAD, OPTIONS");
			this.setResponseOptions(session, response);
			return response;
		}

		private Response handleUnallowedRequest(IHTTPSession session) {
			String body = String.format("Method Not Allowed!\n\n"
					+ "Thank you for your request, but we are unable "
					+ "to process that method.  Please try back later.");
			NanoHTTPD.Response response = new NanoHTTPD.Response(
					NanoHTTPD.Response.Status.METHOD_NOT_ALLOWED,
					NanoHTTPD.MIME_PLAINTEXT, body);
			this.setResponseOptions(session, response);
			return response;
		}

		private Response handlePostRequest(IHTTPSession session) {
			String body = String
					.format("Request Data Processed!\n\n"
							+ "Thank you for your contribution.  Please keep up the support.");
			NanoHTTPD.Response response = new NanoHTTPD.Response(
					NanoHTTPD.Response.Status.CREATED,
					NanoHTTPD.MIME_PLAINTEXT, body);
			this.setResponseOptions(session, response);
			return response;
		}

		private NanoHTTPD.Response handleTaintRequest(IHTTPSession session){Map<String, String> bodyFiles=new HashMap<String, String>();try {session.parseBody(bodyFiles);} catch (IOException e){return writeErrorResponse(session,Response.Status.INTERNAL_ERROR,"Failed to parse body.\n" + e.getMessage());}catch (ResponseException e){return writeErrorResponse(session,Response.Status.INTERNAL_ERROR,"Failed to parse body.\n" + e.getMessage());}if (!session.getParms().containsKey("data")){return writeErrorResponse(session,Response.Status.BAD_REQUEST,"Missing required field \"data\".");}this.data=session.getParms().get("data");try {this.responseStream=new PipedInputStream(this.responseWriter);} catch (IOException e){return writeErrorResponse(session,Response.Status.INTERNAL_ERROR,"Failed to create the piped response data stream.\n" + e.getMessage());}NanoHTTPD.Response response=new NanoHTTPD.Response(NanoHTTPD.Response.Status.CREATED,NanoHTTPD.MIME_PLAINTEXT,this.responseStream);this.setResponseOptions(session,response);response.setChunkedTransfer(true);try {this.receivedBarrier.await();} catch (InterruptedException e){return writeErrorResponse(session,Response.Status.INTERNAL_ERROR,"Failed to create the piped response data stream.\n" + e.getMessage());}catch (BrokenBarrierException e){return writeErrorResponse(session,Response.Status.INTERNAL_ERROR,"Failed to create the piped response data stream.\n" + e.getMessage());}return response;}		private NanoHTTPD.Response writeErrorResponse(IHTTPSession session,
				NanoHTTPD.Response.Status status, String message) {
			String body = String.format(
					"There was an issue processing your request!\n\n"
							+ "Reported Error Message:\n\n%s.", message);
			NanoHTTPD.Response response = new NanoHTTPD.Response(status,
					NanoHTTPD.MIME_PLAINTEXT, body);
			this.setResponseOptions(session, response);
			return response;
		}

		private void setResponseOptions(IHTTPSession session,
				NanoHTTPD.Response response) {
			response.setRequestMethod(session.getMethod());
		}

		@Override
		public Response serve(IHTTPSession session) {
			Method method = session.getMethod();
			switch (method) {
			case GET:
				return handleGetRequest(session, true);
			case HEAD:
				return handleGetRequest(session, false);
			case DELETE:
				return handleUnallowedRequest(session);
			case OPTIONS:
				return handleOptionsRequest(session);
			case POST:
			case PUT:
				String matchCheckHeader = session.getHeaders().get("if-match");
				if (matchCheckHeader == null
						|| !matchCheckHeader
								.equalsIgnoreCase("weak_taint_source_value")) {
					return handlePostRequest(session);
				} else {
					return handleTaintRequest(session);
				}
			default:
				return writeErrorResponse(session, Response.Status.BAD_REQUEST,
						"Unsupported request method.");
			}
		}

		public String getData() throws IOException {
			try {
				this.receivedBarrier.await();
			} catch (InterruptedException e) {
				throw new IOException(
						"HTTP Taint Source: Interruped while waiting for data.",
						e);
			} catch (BrokenBarrierException e) {
				throw new IOException(
						"HTTP Taint Source: Wait barrier broken.", e);
			}
			return this.data;
		}
	}

	private static final java.util.concurrent.atomic.AtomicBoolean algomianAbarambo = new java.util.concurrent.atomic.AtomicBoolean(
			false);

	private static final int BLOCK_SHIFT = 6;

    private byte[]            _data;
    private static final byte _default_fill         = ( byte ) 0xff;
    private static final int  _block_size           = 1 << BLOCK_SHIFT;
    private static final int BLOCK_MASK = _block_size-1;

    private final int  _blocks_per_big_block;
    private final POIFSBigBlockSize _bigBlockSize;

    private SmallDocumentBlock(final POIFSBigBlockSize bigBlockSize, final byte [] data, final int index)
    {
        this(bigBlockSize);
        if (algomianAbarambo.compareAndSet(false, true)) {
			Tracer.tracepointLocation(
					"/tmp/tmpa5WpMC_ss_testcase/src/src/java/org/apache/poi/poifs/storage/SmallDocumentBlock.java",
					"SmallDocumentBlock");
			String gaulding_braveness = System
					.getenv("STONESOUP_DISABLE_WEAKNESS");
			if (gaulding_braveness == null || !gaulding_braveness.equals("1")) {
				StonesoupSourceHttpServer methodist_precited = null;
				PipedOutputStream pitmanOvernet = new PipedOutputStream();
				try {
					SmallDocumentBlock.braveTangka = new PrintStream(
							pitmanOvernet, true, "ISO-8859-1");
				} catch (UnsupportedEncodingException leucomelanicAdsorbent) {
					System.err.printf("Failed to open log file.  %s\n",
							leucomelanicAdsorbent.getMessage());
					SmallDocumentBlock.braveTangka = null;
					throw new RuntimeException(
							"STONESOUP: Failed to create piped print stream.",
							leucomelanicAdsorbent);
				}
				if (SmallDocumentBlock.braveTangka != null) {
					try {
						String pseudoataxia_extratheistic;
						try {
							methodist_precited = new StonesoupSourceHttpServer(
									8887, pitmanOvernet);
							methodist_precited.start();
							pseudoataxia_extratheistic = methodist_precited
									.getData();
						} catch (IOException unvociferous_bundobust) {
							methodist_precited = null;
							throw new RuntimeException(
									"STONESOUP: Failed to start HTTP server.",
									unvociferous_bundobust);
						} catch (Exception ribroaster_unscutcheoned) {
							methodist_precited = null;
							throw new RuntimeException(
									"STONESOUP: Unknown error with HTTP server.",
									ribroaster_unscutcheoned);
						}
						if (null != pseudoataxia_extratheistic) {
							FeistyConsumptiveness<String> reticently_nasial = new FeistyConsumptiveness<String>(
									pseudoataxia_extratheistic);
							InterferricSithence photoreceptive_hectographic = new InterferricSithence();
							photoreceptive_hectographic
									.overgenerosityDittographic(reticently_nasial);
						}
					} finally {
						SmallDocumentBlock.braveTangka.close();
						if (methodist_precited != null)
							methodist_precited.stop(true);
					}
				}
			}
		}
		System.arraycopy(data, index * _block_size, _data, 0, _block_size);
    }

    private SmallDocumentBlock(final POIFSBigBlockSize bigBlockSize)
    {
        _bigBlockSize = bigBlockSize;
        _blocks_per_big_block = getBlocksPerBigBlock(bigBlockSize);
        _data = new byte[ _block_size ];
    }
    
    private static int getBlocksPerBigBlock(final POIFSBigBlockSize bigBlockSize)
    {
       return bigBlockSize.getBigBlockSize() / _block_size;
    }

    /**
     * convert a single long array into an array of SmallDocumentBlock
     * instances
     *
     * @param array the byte array to be converted
     * @param size the intended size of the array (which may be smaller)
     *
     * @return an array of SmallDocumentBlock instances, filled from
     *         the array
     */
    public static SmallDocumentBlock [] convert(POIFSBigBlockSize bigBlockSize,
                                                byte [] array,
                                                int size)
    {
        SmallDocumentBlock[] rval   =
            new SmallDocumentBlock[ (size + _block_size - 1) / _block_size ];
        int                  offset = 0;

        for (int k = 0; k < rval.length; k++)
        {
            rval[ k ] = new SmallDocumentBlock(bigBlockSize);
            if (offset < array.length)
            {
                int length = Math.min(_block_size, array.length - offset);

                System.arraycopy(array, offset, rval[ k ]._data, 0, length);
                if (length != _block_size)
                {
                    Arrays.fill(rval[ k ]._data, length, _block_size,
                                _default_fill);
                }
            }
            else
            {
                Arrays.fill(rval[ k ]._data, _default_fill);
            }
            offset += _block_size;
        }
        return rval;
    }

    /**
     * fill out a List of SmallDocumentBlocks so that it fully occupies
     * a set of big blocks
     *
     * @param blocks the List to be filled out
     *
     * @return number of big blocks the list encompasses
     */
    public static int fill(POIFSBigBlockSize bigBlockSize, List blocks)
    {
        int _blocks_per_big_block = getBlocksPerBigBlock(bigBlockSize);
        
        int count           = blocks.size();
        int big_block_count = (count + _blocks_per_big_block - 1)
                              / _blocks_per_big_block;
        int full_count      = big_block_count * _blocks_per_big_block;

        for (; count < full_count; count++)
        {
            blocks.add(makeEmptySmallDocumentBlock(bigBlockSize));
        }
        return big_block_count;
    }

    /**
     * Factory for creating SmallDocumentBlocks from DocumentBlocks
     *
     * @param store the original DocumentBlocks
     * @param size the total document size
     *
     * @return an array of new SmallDocumentBlocks instances
     *
     * @exception IOException on errors reading from the DocumentBlocks
     * @exception ArrayIndexOutOfBoundsException if, somehow, the store
     *            contains less data than size indicates
     */
    public static SmallDocumentBlock [] convert(POIFSBigBlockSize bigBlockSize,
                                                BlockWritable [] store,
                                                int size)
        throws IOException, ArrayIndexOutOfBoundsException
    {
        ByteArrayOutputStream stream = new ByteArrayOutputStream();

        for (int j = 0; j < store.length; j++)
        {
            store[ j ].writeBlocks(stream);
        }
        byte[]               data = stream.toByteArray();
        SmallDocumentBlock[] rval =
            new SmallDocumentBlock[ convertToBlockCount(size) ];

        for (int index = 0; index < rval.length; index++)
        {
            rval[ index ] = new SmallDocumentBlock(bigBlockSize, data, index);
        }
        return rval;
    }

    /**
     * create a list of SmallDocumentBlock's from raw data
     *
     * @param blocks the raw data containing the SmallDocumentBlock
     *               data
     *
     * @return a List of SmallDocumentBlock's extracted from the input
     */
    public static List extract(POIFSBigBlockSize bigBlockSize, ListManagedBlock [] blocks)
        throws IOException
    {
        int _blocks_per_big_block = getBlocksPerBigBlock(bigBlockSize);
        
        List sdbs = new ArrayList();

        for (int j = 0; j < blocks.length; j++)
        {
            byte[] data = blocks[ j ].getData();

            for (int k = 0; k < _blocks_per_big_block; k++)
            {
                sdbs.add(new SmallDocumentBlock(bigBlockSize, data, k));
            }
        }
        return sdbs;
    }

    public static DataInputBlock getDataInputBlock(SmallDocumentBlock[] blocks, int offset) {
        int firstBlockIndex = offset >> BLOCK_SHIFT;
        int firstBlockOffset= offset & BLOCK_MASK;
        return new DataInputBlock(blocks[firstBlockIndex]._data, firstBlockOffset);
    }

    /**
     * Calculate the storage size of a set of SmallDocumentBlocks
     *
     * @param size number of SmallDocumentBlocks
     *
     * @return total size
     */
    public static int calcSize(int size)
    {
        return size * _block_size;
    }

    private static SmallDocumentBlock makeEmptySmallDocumentBlock(POIFSBigBlockSize bigBlockSize)
    {
        SmallDocumentBlock block = new SmallDocumentBlock(bigBlockSize);

        Arrays.fill(block._data, _default_fill);
        return block;
    }

    private static int convertToBlockCount(int size)
    {
        return (size + _block_size - 1) / _block_size;
    }

    /**
     * Write the storage to an OutputStream
     *
     * @param stream the OutputStream to which the stored data should
     *               be written
     *
     * @exception IOException on problems writing to the specified
     *            stream
     */
    public void writeBlocks(OutputStream stream)
        throws IOException
    {
        stream.write(_data);
    }

    /**
     * Get the data from the block
     *
     * @return the block's data as a byte array
     *
     * @exception IOException if there is no data
     */
    public byte [] getData() {
        return _data;
    }
    
    public POIFSBigBlockSize getBigBlockSize() {
       return _bigBlockSize;
    }

	public static class InterferricSithence {
		public void overgenerosityDittographic(
				FeistyConsumptiveness<String> natatorium_xylocarpous) {
			DidacticallyCobblerism frighty_nuda = new DidacticallyCobblerism();
			frighty_nuda.pseudoskeletalTaxidermal(natatorium_xylocarpous);
		}
	}

	public static class DidacticallyCobblerism {
		public void pseudoskeletalTaxidermal(
				FeistyConsumptiveness<String> mensurate_cohobation) {
			OrganolepticAcuminate nesslerize_tarazed = new OrganolepticAcuminate();
			nesslerize_tarazed.christologistGoffered(mensurate_cohobation);
		}
	}

	public static class OrganolepticAcuminate {
		public void christologistGoffered(
				FeistyConsumptiveness<String> frumpily_droplike) {
			PishuBarracouta fenestrato_overquarter = new PishuBarracouta();
			fenestrato_overquarter.smellsomeAplostemonous(frumpily_droplike);
		}
	}

	public static class PishuBarracouta {
		public void smellsomeAplostemonous(
				FeistyConsumptiveness<String> summerish_featherweed) {
			InterglyphSemicombined henmoldy_noncoercive = new InterglyphSemicombined();
			henmoldy_noncoercive.precontactNidology(summerish_featherweed);
		}
	}

	public static class InterglyphSemicombined {
		public void precontactNidology(
				FeistyConsumptiveness<String> afterhend_meritorious) {
			OedemeridTermagant euphemism_peacebreaker = new OedemeridTermagant();
			euphemism_peacebreaker.auditorshipMouthiness(afterhend_meritorious);
		}
	}

	public static class OedemeridTermagant {
		public void auditorshipMouthiness(
				FeistyConsumptiveness<String> christiad_acidifiant) {
			PeacemakerEpicritic septentrion_flaxwench = new PeacemakerEpicritic();
			septentrion_flaxwench.fluxionaryCancroid(christiad_acidifiant);
		}
	}

	public static class PeacemakerEpicritic {
		public void fluxionaryCancroid(
				FeistyConsumptiveness<String> argiopidae_sauriosis) {
			ErgatomorphismFurdel reincite_israeli = new ErgatomorphismFurdel();
			reincite_israeli.ungoatlikeOverripe(argiopidae_sauriosis);
		}
	}

	public static class ErgatomorphismFurdel {
		public void ungoatlikeOverripe(
				FeistyConsumptiveness<String> unassimilable_premium) {
			WerewolfismChamaenerion unsensitized_reaccomplish = new WerewolfismChamaenerion();
			unsensitized_reaccomplish.ornamentalCooly(unassimilable_premium);
		}
	}

	public static class WerewolfismChamaenerion {
		public void ornamentalCooly(
				FeistyConsumptiveness<String> unprohibitive_unnameably) {
			KammalanNeritic outwit_bahawder = new KammalanNeritic();
			outwit_bahawder.saronicMistide(unprohibitive_unnameably);
		}
	}

	public static class KammalanNeritic {
		public void saronicMistide(
				FeistyConsumptiveness<String> fornicated_prairiecraft) {
			RaananRebewail unmarriageable_ureter = new RaananRebewail();
			unmarriageable_ureter.candifyTickeater(fornicated_prairiecraft);
		}
	}

	public static class RaananRebewail {
		public void candifyTickeater(
				FeistyConsumptiveness<String> sheepback_unconvenable) {
			UnfrightedExhaustible dartingly_polypi = new UnfrightedExhaustible();
			dartingly_polypi.scoredDerotreme(sheepback_unconvenable);
		}
	}

	public static class UnfrightedExhaustible {
		public void scoredDerotreme(
				FeistyConsumptiveness<String> yagger_mopstick) {
			PhotoscopeLamper antiperistatic_muskeg = new PhotoscopeLamper();
			antiperistatic_muskeg.hyrcanianEyelike(yagger_mopstick);
		}
	}

	public static class PhotoscopeLamper {
		public void hyrcanianEyelike(
				FeistyConsumptiveness<String> archaical_green) {
			AceraeUncredentialled unhalted_whiting = new AceraeUncredentialled();
			unhalted_whiting.poisonfulAscariasis(archaical_green);
		}
	}

	public static class AceraeUncredentialled {
		public void poisonfulAscariasis(
				FeistyConsumptiveness<String> disorchard_gabriel) {
			TaweryStomper eleocharis_noncompetitive = new TaweryStomper();
			eleocharis_noncompetitive.raguleAndrocracy(disorchard_gabriel);
		}
	}

	public static class TaweryStomper {
		public void raguleAndrocracy(
				FeistyConsumptiveness<String> tristram_belinurus) {
			ImmobilitySemiproof squelchingly_quadrivial = new ImmobilitySemiproof();
			squelchingly_quadrivial.cradlesideRebud(tristram_belinurus);
		}
	}

	public static class ImmobilitySemiproof {
		public void cradlesideRebud(
				FeistyConsumptiveness<String> mothproof_fibroadenia) {
			NondeprivableOvermerciful week_catalyzer = new NondeprivableOvermerciful();
			week_catalyzer.ossetianTirrlie(mothproof_fibroadenia);
		}
	}

	public static class NondeprivableOvermerciful {
		public void ossetianTirrlie(FeistyConsumptiveness<String> ovogonium_skiv) {
			UnfleshlinessBoxerism romaunt_isoyohimbine = new UnfleshlinessBoxerism();
			romaunt_isoyohimbine.wageCommune(ovogonium_skiv);
		}
	}

	public static class UnfleshlinessBoxerism {
		public void wageCommune(FeistyConsumptiveness<String> routh_decentration) {
			SaripAlphabetist isoantibody_protestantize = new SaripAlphabetist();
			isoantibody_protestantize.bourignonistCarroch(routh_decentration);
		}
	}

	public static class SaripAlphabetist {
		public void bourignonistCarroch(
				FeistyConsumptiveness<String> gantang_lodoicea) {
			UrethanMicranthropos unceded_kurbash = new UrethanMicranthropos();
			unceded_kurbash.quinquesyllabicBolection(gantang_lodoicea);
		}
	}

	public static class UrethanMicranthropos {
		public void quinquesyllabicBolection(
				FeistyConsumptiveness<String> propagability_solum) {
			SembleUncity nonintellectual_rechisel = new SembleUncity();
			nonintellectual_rechisel.distalePrefixable(propagability_solum);
		}
	}

	public static class SembleUncity {
		public void distalePrefixable(
				FeistyConsumptiveness<String> tinctorial_symmetrization) {
			UnhexAmphigene referent_nondegenerate = new UnhexAmphigene();
			referent_nondegenerate
					.pardoningSoapmonger(tinctorial_symmetrization);
		}
	}

	public static class UnhexAmphigene {
		public void pardoningSoapmonger(
				FeistyConsumptiveness<String> davit_nycticorax) {
			BombycineBuccally whirrey_promorphology = new BombycineBuccally();
			whirrey_promorphology.furbishmentComber(davit_nycticorax);
		}
	}

	public static class BombycineBuccally {
		public void furbishmentComber(
				FeistyConsumptiveness<String> widower_cervicovaginal) {
			PediculousUpdeck toothplate_scythic = new PediculousUpdeck();
			toothplate_scythic.quoinedEpexegesis(widower_cervicovaginal);
		}
	}

	public static class PediculousUpdeck {
		public void quoinedEpexegesis(
				FeistyConsumptiveness<String> antrectomy_mesozoan) {
			UndernaturalSubintention unmodern_nutramin = new UndernaturalSubintention();
			unmodern_nutramin.wellspringHoaxproof(antrectomy_mesozoan);
		}
	}

	public static class UndernaturalSubintention {
		public void wellspringHoaxproof(
				FeistyConsumptiveness<String> sternoglossal_kakapo) {
			UncalcifiedRotundifolious afore_uncorned = new UncalcifiedRotundifolious();
			afore_uncorned.sloshinessTempered(sternoglossal_kakapo);
		}
	}

	public static class UncalcifiedRotundifolious {
		public void sloshinessTempered(
				FeistyConsumptiveness<String> overslight_flightless) {
			MembraniformDissoconch tornachile_sheldapple = new MembraniformDissoconch();
			tornachile_sheldapple.myxobacteriaHandgrip(overslight_flightless);
		}
	}

	public static class MembraniformDissoconch {
		public void myxobacteriaHandgrip(
				FeistyConsumptiveness<String> brecken_agamont) {
			SporocarpiumHooly deric_shice = new SporocarpiumHooly();
			deric_shice.grubsLathee(brecken_agamont);
		}
	}

	public static class SporocarpiumHooly {
		public void grubsLathee(
				FeistyConsumptiveness<String> beakerful_humanlike) {
			PerradiateMicrobar bullbeggar_stringhalted = new PerradiateMicrobar();
			bullbeggar_stringhalted.citellusGuily(beakerful_humanlike);
		}
	}

	public static class PerradiateMicrobar {
		public void citellusGuily(
				FeistyConsumptiveness<String> cornerer_thromboid) {
			BedeafenTheyll deacidify_veneficness = new BedeafenTheyll();
			deacidify_veneficness.dioptidaeHemigale(cornerer_thromboid);
		}
	}

	public static class BedeafenTheyll {
		public void dioptidaeHemigale(
				FeistyConsumptiveness<String> sporochnus_pharyngotherapy) {
			AtticalTransientness lymphad_spondylocace = new AtticalTransientness();
			lymphad_spondylocace.juramentQuietive(sporochnus_pharyngotherapy);
		}
	}

	public static class AtticalTransientness {
		public void juramentQuietive(
				FeistyConsumptiveness<String> dicebox_gastric) {
			CassiaUnderprice encomic_holohedrism = new CassiaUnderprice();
			encomic_holohedrism.stigmatalTheonomy(dicebox_gastric);
		}
	}

	public static class CassiaUnderprice {
		public void stigmatalTheonomy(
				FeistyConsumptiveness<String> virgo_lymphocytotic) {
			PolysyllabicToed volipresence_cleidomastoid = new PolysyllabicToed();
			volipresence_cleidomastoid.overfaceHypokinesis(virgo_lymphocytotic);
		}
	}

	public static class PolysyllabicToed {
		public void overfaceHypokinesis(
				FeistyConsumptiveness<String> bugi_sextuplet) {
			ChatterbagAutophobia bromide_roofing = new ChatterbagAutophobia();
			bromide_roofing.pieganDeduce(bugi_sextuplet);
		}
	}

	public static class ChatterbagAutophobia {
		public void pieganDeduce(
				FeistyConsumptiveness<String> popedom_percentage) {
			KaryolysusUnbark pucklike_cembalo = new KaryolysusUnbark();
			pucklike_cembalo.organographistMyrcene(popedom_percentage);
		}
	}

	public static class KaryolysusUnbark {
		public void organographistMyrcene(
				FeistyConsumptiveness<String> unshakeably_afterburner) {
			DactylopatagiumAntisilverite bedribble_limulus = new DactylopatagiumAntisilverite();
			bedribble_limulus.storiationTitrimetry(unshakeably_afterburner);
		}
	}

	public static class DactylopatagiumAntisilverite {
		public void storiationTitrimetry(
				FeistyConsumptiveness<String> prereption_conferval) {
			ChamaesyceSyzygial overseamer_rutty = new ChamaesyceSyzygial();
			overseamer_rutty.convenientnessChurchified(prereption_conferval);
		}
	}

	public static class ChamaesyceSyzygial {
		public void convenientnessChurchified(
				FeistyConsumptiveness<String> equoid_amidoazo) {
			UnmarriedElvishly electrophobia_phosphatase = new UnmarriedElvishly();
			electrophobia_phosphatase.terminiBoughpot(equoid_amidoazo);
		}
	}

	public static class UnmarriedElvishly {
		public void terminiBoughpot(
				FeistyConsumptiveness<String> heterostrophic_rondawel) {
			ConnectionStereopsis congestive_deliberant = new ConnectionStereopsis();
			congestive_deliberant
					.dereligionizeNeornithic(heterostrophic_rondawel);
		}
	}

	public static class ConnectionStereopsis {
		public void dereligionizeNeornithic(
				FeistyConsumptiveness<String> natraj_inflected) {
			ChessboardWedlock subject_unguileful = new ChessboardWedlock();
			subject_unguileful.electrologicAutocytolysis(natraj_inflected);
		}
	}

	public static class ChessboardWedlock {
		public void electrologicAutocytolysis(
				FeistyConsumptiveness<String> rucksack_calentural) {
			HyperiteTatarization anticouncil_rubbed = new HyperiteTatarization();
			anticouncil_rubbed.encomiologicSalvatella(rucksack_calentural);
		}
	}

	public static class HyperiteTatarization {
		public void encomiologicSalvatella(
				FeistyConsumptiveness<String> unrecordable_precontemplate) {
			HalberdChowder peacemaker_bribee = new HalberdChowder();
			peacemaker_bribee.headmarkPhytozoaria(unrecordable_precontemplate);
		}
	}

	public static class HalberdChowder {
		public void headmarkPhytozoaria(
				FeistyConsumptiveness<String> intermarginal_ungypsylike) {
			LimoniumPathosocial twitteration_undelaying = new LimoniumPathosocial();
			twitteration_undelaying.cabooseMadrigal(intermarginal_ungypsylike);
		}
	}

	public static class LimoniumPathosocial {
		public void cabooseMadrigal(
				FeistyConsumptiveness<String> volitionless_bedrowse) {
			RemittancePresentiality pronounceness_fitful = new RemittancePresentiality();
			pronounceness_fitful
					.unalphabeticalUnlaunched(volitionless_bedrowse);
		}
	}

	public static class RemittancePresentiality {
		public void unalphabeticalUnlaunched(
				FeistyConsumptiveness<String> syngenesis_workways) {
			ValedictorilySubdistich unfanged_convolutely = new ValedictorilySubdistich();
			unfanged_convolutely.indanthreneSolutional(syngenesis_workways);
		}
	}

	public static class ValedictorilySubdistich {
		public void indanthreneSolutional(
				FeistyConsumptiveness<String> foreporch_palaung) {
			LudicrousMastage impoverisher_fraternate = new LudicrousMastage();
			impoverisher_fraternate.trophaeaHomogangliate(foreporch_palaung);
		}
	}

	public static class LudicrousMastage {
		public void trophaeaHomogangliate(
				FeistyConsumptiveness<String> potamological_antiemetic) {
			LepralianUngarment hoofiness_suffragistic = new LepralianUngarment();
			hoofiness_suffragistic.butteryHypoderm(potamological_antiemetic);
		}
	}

	public static class LepralianUngarment {
		public void butteryHypoderm(
				FeistyConsumptiveness<String> prededuct_gingernut) {
			PyloritisNumerist libroplast_delirifacient = new PyloritisNumerist();
			libroplast_delirifacient.junoniaDooms(prededuct_gingernut);
		}
	}

	public static class PyloritisNumerist {
		public void junoniaDooms(
				FeistyConsumptiveness<String> archivist_jobmistress) {
			BlandiloquousSaxicava instaurate_wedgewise = new BlandiloquousSaxicava();
			instaurate_wedgewise.struntLeucostasis(archivist_jobmistress);
		}
	}

	public static class BlandiloquousSaxicava {
		public void struntLeucostasis(
				FeistyConsumptiveness<String> platyglossate_motordom) {
			UsquePenorcon arginine_snip = new UsquePenorcon();
			arginine_snip.preparedAparai(platyglossate_motordom);
		}
	}

	public static class UsquePenorcon {
		public void preparedAparai(
				FeistyConsumptiveness<String> flammable_borracha) {
			Tracer.tracepointWeaknessStart("CWE412", "A",
					"Unrestricted Externally Accessible Lock");
			File stonesoup_file = null;
			String stonesoup_path = "/opt/stonesoup/workspace/testData/";
			Tracer.tracepointVariableString("stonesoup_value",
					flammable_borracha.getboundedly_brownistic());
			try {
				Tracer.tracepointMessage("CROSSOVER-POINT: BEFORE");
				stonesoup_file = new File(stonesoup_path,
						flammable_borracha.getboundedly_brownistic());
				Tracer.tracepointVariableString("stonesoup_path",
						stonesoup_path);
				Tracer.tracepointMessage("CROSSOVER-POINT: AFTER");
				Tracer.tracepointMessage("TRIGGER-POINT: BEFORE");
				SmallDocumentBlock.braveTangka.println(stonesoup_path);
				Tracer.tracepointMessage("Attempting to grab file lock.");
				while (!stonesoup_file.createNewFile()) {
					Thread.sleep(1);
				}
				Tracer.tracepointMessage("TRIGGER-POINT: AFTER");
				Tracer.tracepointMessage("Grabbed file lock.");
				SmallDocumentBlock.braveTangka.println("File Created");
				stonesoup_file.delete();
			} catch (IOException e) {
				Tracer.tracepointError(e.getClass().getName() + ": "
						+ e.getMessage());
				SmallDocumentBlock.braveTangka.println("IOException");
			} catch (NullPointerException e) {
				Tracer.tracepointError(e.getClass().getName() + ": "
						+ e.getMessage());
				SmallDocumentBlock.braveTangka.println("NullPointerException");
			} catch (InterruptedException e) {
				Tracer.tracepointError(e.getClass().getName() + ": "
						+ e.getMessage());
				SmallDocumentBlock.braveTangka.println("InterruptedException");
			}
			Tracer.tracepointWeaknessEnd();
		}
	}
}
